@@ -26,7 +26,7 @@ function run_tests {
   local exit_code=0
 
   while read cmd; do 
-    # echo "RUNNING: $cmd"
+     echo "RUNNING: $cmd"
     if eval "$cmd"; then
       echo "PASSED: $cmd"
     else
