@@ -20,20 +20,12 @@
  */
 package org.sejda.core.support.prefix;
 
-import static org.apache.commons.lang3.StringUtils.repeat;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.lessThan;
-import static org.hamcrest.core.StringEndsWith.endsWith;
-import static org.hamcrest.core.StringStartsWith.startsWith;
 import static org.junit.Assert.assertEquals;
 import static org.sejda.core.support.prefix.NameGenerator.nameGenerator;
 import static org.sejda.core.support.prefix.model.NameGenerationRequest.nameRequest;
-import static org.hamcrest.Matchers.is;
 
 import org.junit.Test;
 
-import java.nio.charset.StandardCharsets;
-
 /**
  * Test unit for the NameGenerator
  * 
@@ -76,35 +68,21 @@ public class NameGeneratorTest {
         assertEquals(expected, nameGenerator(prefix).generate(nameRequest().originalName(originalName)));
     }
 
+    @Test
+    public void reuseSameNameGenerator() {
+        NameGenerator generator = nameGenerator("BLA_[CURRENTPAGE###]_[BASENAME]");
+        String originalName = "Original";
+        assertEquals("BLA_001_Original.pdf", generator.generate(nameRequest().originalName(originalName).page(1)));
+        assertEquals("BLA_005_Original.pdf", generator.generate(nameRequest().originalName(originalName).page(5)));
+        assertEquals("BLA_010_Original.pdf", generator.generate(nameRequest().originalName(originalName).page(10)));
+    }
+
     @Test(expected = IllegalArgumentException.class)
     public void testNullRequest() {
         String prefix = "BLA_";
         nameGenerator(prefix).generate(null);
     }
 
-    @Test
-    public void testMaxFilenameSize() {
-        String generatedFilename = nameGenerator("BLA_[TEXT]").generate(nameRequest("pdf").text(repeat('a', 300)));
-        assertEquals(255, generatedFilename.length());
-        assertThat(generatedFilename, endsWith("aaa.pdf"));
-    }
-
-    @Test
-    public void testMaxFilenameSizeUnicode() {
-        String generatedFilename = nameGenerator("compressed_").generate(nameRequest("pdf").originalName(repeat("aว", 300)));
-        assertThat(generatedFilename.length(), is(lessThan(256)));
-        assertThat(generatedFilename, endsWith(".pdf"));
-        assertThat(generatedFilename, startsWith("compressed_aวaว"));
-    }
-
-    @Test
-    public void testMaxFilenameSizeSanitized() {
-        String generatedFilename = nameGenerator("B|LA_[TEXT]").generate(nameRequest("pdf").text(repeat('a', 300)));
-        assertEquals(255, generatedFilename.length());
-        assertThat(generatedFilename, endsWith("aaa.pdf"));
-        assertThat(generatedFilename, startsWith("BLA_aaa"));
-    }
-
     @Test
     public void testInvalidCharacters() {
         String generatedFilename = nameGenerator("Invalid_\\").generate(nameRequest("pdf"));
@@ -118,26 +96,17 @@ public class NameGeneratorTest {
         assertEquals(generatedFilename, "99-My file 6-04-2015 $1234-56.pdf");
     }
 
-    // convenience method, don't pass charset and len all the time
-    private String shortenFilenameBytesLength(String input) {
-        return NameGenerator.shortenFilenameBytesLength(input, 255, StandardCharsets.UTF_8);
-    }
-
-    private String largeFilename = repeat("aว", 300) + ".pdf";
-
     @Test
-    public void shortenFilenameBytesLength() {
-        String shorter = shortenFilenameBytesLength(largeFilename);
-        assertThat(shorter, endsWith("aวaวa.pdf"));
-        assertThat(shorter, startsWith("aวaว"));
-        assertThat(shorter.getBytes(StandardCharsets.UTF_8).length, is(253));
+    public void testSuffix() {
+        String generatedFilename = nameGenerator("[BASENAME]_suffix")
+                .generate(nameRequest("pdf").originalName("My file"));
+        assertEquals(generatedFilename, "My file_suffix.pdf");
     }
 
     @Test
-    public void shortenFilenameCharLength() {
-        String shorter = NameGenerator.shortenFilenameCharLength(largeFilename, 255);
-        assertThat(shorter, endsWith("aวaวa.pdf"));
-        assertThat(shorter, startsWith("aวaว"));
-        assertThat(shorter.length(), is(255));
+    public void testPrefixSuffix() {
+        String generatedFilename = nameGenerator("prefix_[BASENAME]_suffix")
+                .generate(nameRequest("pdf").originalName("My file"));
+        assertEquals(generatedFilename, "prefix_My file_suffix.pdf");
     }
 }
