@@ -20,9 +20,14 @@ package org.sejda.model.parameter.image;
 
 import org.apache.commons.lang3.builder.EqualsBuilder;
 import org.apache.commons.lang3.builder.HashCodeBuilder;
-import org.sejda.model.parameter.PageOrientation;
-import org.sejda.model.parameter.PageSize;
+import org.sejda.model.PageOrientation;
+import org.sejda.model.PageSize;
 import org.sejda.model.parameter.base.MultipleSourceSingleOutputParameters;
+import org.sejda.model.rotation.Rotation;
+
+import javax.validation.Valid;
+import java.util.ArrayList;
+import java.util.List;
 
 public class JpegToPdfParameters extends MultipleSourceSingleOutputParameters {
 
@@ -31,6 +36,9 @@ public class JpegToPdfParameters extends MultipleSourceSingleOutputParameters {
     private PageOrientation pageOrientation = PageOrientation.AUTO;
     private float marginInches;
 
+    @Valid
+    private List<Rotation> rotations = new ArrayList<>();
+
     @Override
     public boolean equals(Object o) {
         if (this == o) return true;
@@ -44,6 +52,7 @@ public class JpegToPdfParameters extends MultipleSourceSingleOutputParameters {
                 .append(pageSize, other.pageSize)
                 .append(pageOrientation, other.pageOrientation)
                 .append(marginInches, other.marginInches)
+                .append(rotations, other.rotations)
                 .isEquals();
     }
 
@@ -55,6 +64,7 @@ public class JpegToPdfParameters extends MultipleSourceSingleOutputParameters {
                 .append(pageSizeMatchImageSize)
                 .append(pageOrientation)
                 .append(marginInches)
+                .append(rotations)
                 .toHashCode();
     }
 
@@ -89,4 +99,12 @@ public class JpegToPdfParameters extends MultipleSourceSingleOutputParameters {
     public void setMarginInches(float marginInches) {
         this.marginInches = marginInches;
     }
+
+    public List<Rotation> getRotations() {
+        return rotations;
+    }
+
+    public void setRotations(List<Rotation> rotations) {
+        this.rotations = rotations;
+    }
 }
