@@ -43,7 +43,6 @@ import org.sejda.model.pdf.PdfVersion;
 import org.sejda.model.pdf.label.PdfPageLabel;
 import org.sejda.model.pdf.viewerpreference.PdfPageLayout;
 import org.sejda.model.pdf.viewerpreference.PdfPageMode;
-import org.sejda.sambox.contentstream.PDContentStream;
 import org.sejda.sambox.cos.COSDictionary;
 import org.sejda.sambox.cos.COSName;
 import org.sejda.sambox.encryption.StandardSecurity;
@@ -53,12 +52,9 @@ import org.sejda.sambox.pdmodel.PDDocumentCatalog;
 import org.sejda.sambox.pdmodel.PDDocumentInformation;
 import org.sejda.sambox.pdmodel.PDPage;
 import org.sejda.sambox.pdmodel.PDPageTree;
-import org.sejda.sambox.pdmodel.PDResources;
 import org.sejda.sambox.pdmodel.PageLayout;
 import org.sejda.sambox.pdmodel.PageMode;
 import org.sejda.sambox.pdmodel.common.PDRectangle;
-import org.sejda.sambox.pdmodel.font.PDFont;
-import org.sejda.sambox.pdmodel.graphics.PDXObject;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.outline.PDDocumentOutline;
 import org.sejda.sambox.pdmodel.interactive.form.PDAcroForm;
 import org.sejda.sambox.pdmodel.interactive.viewerpreferences.PDViewerPreferences;
@@ -426,50 +422,4 @@ public class PDDocumentHandler implements Closeable {
         document.getPages().insertBefore(result, target);
         return result;
     }
-
-    private PDFont findFont(PDResources resources, String searchedName, Set<PDResources> alreadyVisited) {
-        for (COSName fontName : resources.getFontNames()) {
-            try {
-                PDFont font = resources.getFont(fontName);
-                if (font != null && font.getName() != null && searchedName.equalsIgnoreCase(font.getName())) {
-                    return font;
-                }
-            } catch (Exception e) {
-                LOG.warn("Failure while searching font in resources", e);
-            }
-        }
-
-        for (COSName objectName : resources.getXObjectNames()) {
-            try {
-                PDXObject pdxObject = resources.getXObject(objectName);
-                if (pdxObject instanceof PDContentStream) {
-                    PDResources res = ((PDContentStream) pdxObject).getResources();
-                    if (alreadyVisited.contains(res)) {
-                        continue;
-                    }
-                    alreadyVisited.add(res);
-
-                    PDFont font = findFont(res, searchedName, alreadyVisited);
-                    if (font != null) {
-                        return font;
-                    }
-                }
-            } catch (Exception e) {
-                LOG.warn("Failure while searching font in XObject", e);
-            }
-        }
-
-        return null;
-    }
-
-    public PDFont findFont(String searchedName) {
-        for (PDPage page : document.getPages()) {
-            PDFont font = findFont(page.getResources(), searchedName, new HashSet<>());
-            if (font != null) {
-                return font;
-            }
-        }
-
-        return null;
-    }
 }
