@@ -18,19 +18,19 @@
  */
 package org.sejda.impl.sambox.component.image;
 
+import java.io.IOException;
+
+import org.sejda.model.input.FileSource;
+import org.sejda.model.input.Source;
+import org.sejda.model.input.SourceDispatcher;
+import org.sejda.model.input.StreamSource;
+
 import com.drew.imaging.ImageMetadataReader;
 import com.drew.imaging.ImageProcessingException;
 import com.drew.metadata.Directory;
 import com.drew.metadata.Metadata;
 import com.drew.metadata.MetadataException;
 import com.drew.metadata.exif.ExifIFD0Directory;
-import org.sejda.model.exception.TaskIOException;
-import org.sejda.model.input.FileSource;
-import org.sejda.model.input.Source;
-import org.sejda.model.input.SourceDispatcher;
-import org.sejda.model.input.StreamSource;
-
-import java.io.IOException;
 
 /**
  * Reads exif orientation of an image and determines if the image should be rotated or not.
@@ -42,7 +42,7 @@ public class ExifHelper {
         try {
             return imageSource.dispatch(new SourceDispatcher<Integer>() {
                 @Override
-                public Integer dispatch(FileSource source) throws TaskIOException {
+                public Integer dispatch(FileSource source) {
                     try {
                         int orientation = readExifOrientation(ImageMetadataReader.readMetadata(source.getSource()));
                         return getRotation(orientation);
@@ -52,7 +52,7 @@ public class ExifHelper {
                 }
 
                 @Override
-                public Integer dispatch(StreamSource source) throws TaskIOException {
+                public Integer dispatch(StreamSource source) {
                     try {
                         int orientation = readExifOrientation(ImageMetadataReader.readMetadata(source.getSource()));
                         return getRotation(orientation);
