@@ -41,6 +41,7 @@ import org.sejda.impl.sambox.component.DocBuilder;
 import org.sejda.impl.sambox.component.PdfTextExtractorByArea;
 import org.sejda.model.exception.TaskIOException;
 import org.sejda.model.input.ImageMergeInput;
+import org.sejda.model.input.MergeInput;
 import org.sejda.model.input.PdfMergeInput;
 import org.sejda.model.outline.CatalogPageLabelsPolicy;
 import org.sejda.model.outline.OutlinePolicy;
@@ -49,6 +50,7 @@ import org.sejda.model.parameter.MergeParameters;
 import org.sejda.model.pdf.PdfVersion;
 import org.sejda.model.pdf.form.AcroFormPolicy;
 import org.sejda.model.pdf.page.PageRange;
+import org.sejda.model.rotation.Rotation;
 import org.sejda.model.task.Task;
 import org.sejda.model.toc.ToCPolicy;
 import org.sejda.sambox.pdmodel.PDDocument;
@@ -68,12 +70,12 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         return new MergeTask();
     }
 
-    private MergeParameters setUpParameters(List<PdfMergeInput> input) {
+    private MergeParameters setUpParameters(List<? extends MergeInput> input) {
         MergeParameters parameters = new MergeParameters();
         parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
         parameters.setCompress(false);
         parameters.setVersion(PdfVersion.VERSION_1_6);
-        for (PdfMergeInput current : input) {
+        for (MergeInput current : input) {
             parameters.addInput(current);
         }
         parameters.setOutlinePolicy(OutlinePolicy.RETAIN);
@@ -549,6 +551,26 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         });
     }
 
+    @Test
+    public void mergeImagesAndPdfsWithSpecificPageSize() throws IOException {
+        MergeParameters parameters = new MergeParameters();
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+
+        ImageMergeInput image = new ImageMergeInput(customNonPdfInput("image/draft.png"));
+        image.setShouldPageSizeMatchImageSize(true);
+
+        parameters.addInput(image);
+        parameters.addInput(new PdfMergeInput(customInput("pdf/test-pdf.pdf")));
+
+        testContext.pdfOutputTo(parameters);
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.forEachPdfOutput(d -> {
+            assertEquals(d.getPage(0).getMediaBox().getWidth(), 248, 0.0);
+        });
+    }
+
     @Test
     public void mergeImagesWithTocAndFooter() throws IOException {
         MergeParameters parameters = new MergeParameters();
@@ -599,7 +621,7 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         execute(parameters);
 
         // TODO: friendlier error message
-        testContext.assertTaskFailed("org.sejda.model.exception.TaskIOException: An error occurred creating PDImageXObject from file source: corrupt.png");
+        testContext.assertTaskFailed("An error occurred creating PDImageXObject from file source: corrupt.png");
     }
 
     @Test
@@ -743,6 +765,53 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         });
     }
 
+    @Test
+    public void withoutRotations() throws IOException {
+        List<MergeInput> inputs = new ArrayList<MergeInput>();
+        inputs.add(new PdfMergeInput(shortInput())); // 4 pages, cover/title doc
+        inputs.add(new ImageMergeInput(customNonPdfInput("image/draft.png", "draft.png")));
+
+        MergeParameters parameters = setUpParameters(inputs);
+
+        testContext.pdfOutputTo(parameters);
+
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.assertPages(5).forEachPdfOutput(d -> {
+            assertEquals(d.getPage(0).getRotation(), 0);
+            assertEquals(d.getPage(1).getRotation(), 0);
+            assertEquals(d.getPage(2).getRotation(), 0);
+            assertEquals(d.getPage(3).getRotation(), 0);
+
+            assertEquals(d.getPage(4).getRotation(), 0);
+        });
+    }
+
+    @Test
+    public void withRotations() throws IOException {
+        List<MergeInput> inputs = new ArrayList<MergeInput>();
+        inputs.add(new PdfMergeInput(shortInput())); // 4 pages, cover/title doc
+        inputs.add(new ImageMergeInput(customNonPdfInput("image/draft.png", "draft.png")));
+
+        MergeParameters parameters = setUpParameters(inputs);
+        parameters.setRotations(Arrays.asList(Rotation.DEGREES_90, Rotation.DEGREES_180));
+
+        testContext.pdfOutputTo(parameters);
+
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.assertPages(5).forEachPdfOutput(d -> {
+            assertEquals(d.getPage(0).getRotation(), 90);
+            assertEquals(d.getPage(1).getRotation(), 90);
+            assertEquals(d.getPage(2).getRotation(), 90);
+            assertEquals(d.getPage(3).getRotation(), 90);
+
+            assertEquals(d.getPage(4).getRotation(), 180);
+        });
+    }
+
     private float widthOfCropBox(PDPage page) {
         return page.getCropBox().rotate(page.getRotation()).getWidth();
     }
